"use strict";

var bothGlobsExpanded, browserify, createBundler, fs, glob, glob1, glob1expanded, glob2, glob2expanded, globbedBrowserify, here, path, predictGlob;
path = require('path');
fs = require('fs');
browserify = require('browserify');
glob = require('glob');
globbedBrowserify = require('./index');
here = process.cwd();

predictGlob = function predictGlob(...infix) {
  return [1, 2, 3].map(function (num) {
    return `${path.join(here, ...infix)}${num}.coffee`;
  });
};

glob1 = path.join('fixture', '*.coffee');
glob2 = '*.coffee';
glob1expanded = predictGlob('fixture', 'entry');
glob2expanded = glob.sync(glob2, {
  absolute: true
});
bothGlobsExpanded = glob1expanded.concat(glob2expanded);

createBundler = function createBundler() {
  return globbedBrowserify({
    entries: glob1,
    extensions: ['.coffee']
  }).transform('coffeeify').transform('babelify', {
    presets: ['@babel/env'],
    targets: {
      node: 6
    },
    extensions: ['.coffee']
  });
};

describe('expandGlobsSync', function () {
  var expandGlobsSync;
  var _globbedBrowserify = globbedBrowserify;
  expandGlobsSync = _globbedBrowserify.expandGlobsSync;
  it('returns an array of matching absolute paths', function () {
    expect(expandGlobsSync([glob1])).toEqual(glob1expanded);
    return expect(expandGlobsSync([glob2])).toEqual(glob2expanded);
  });
  return it('also works with multiple globs', function () {
    return expect(expandGlobsSync([glob1, glob2])).toEqual(bothGlobsExpanded);
  });
});
describe('expandGlobs', function () {
  var expandGlobs;
  var _globbedBrowserify2 = globbedBrowserify;
  expandGlobs = _globbedBrowserify2.expandGlobs;
  it('completes with an array of matching absolute paths', function (done) {
    return expandGlobs([glob1], function (error, result) {
      expect(result).toEqual(glob1expanded);
      return expandGlobs([glob2], function (error, result) {
        expect(result).toEqual(glob2expanded);
        return done();
      });
    });
  });
  return it('also works with multiple globs', function (done) {
    return expandGlobs([glob1, glob2], function (error, result) {
      expect(result).toEqual(bothGlobsExpanded);
      return done();
    });
  });
});
describe('difference', function () {
  var difference, set1, set2;
  var _globbedBrowserify3 = globbedBrowserify;
  difference = _globbedBrowserify3.difference;
  set1 = new Set([1, 2, 3]);
  set2 = new Set([3, 4, 5]);
  return it('returns a new set with the elements in the first not in the second', function () {
    var onlyIn1;
    onlyIn1 = difference(set1, set2);
    expect(onlyIn1.has(1)).toBeTruthy();
    expect(onlyIn1.has(2)).toBeTruthy();
    expect(onlyIn1.has(3)).toBeFalsy();
    expect(onlyIn1.has(4)).toBeFalsy();
    return expect(onlyIn1.has(5)).toBeFalsy();
  });
});
describe('globbedBrowserify', function () {
  beforeEach(function () {
    return this.instance = createBundler();
  });
  return it('returns an augmented browserify instance', function () {
    expect(this.instance instanceof browserify).toBe(true);
    expect(this.instance.watch).toBeDefined();
    return expect(this.instance.wrap).toBeDefined();
  });
});
describe('updateEntries', function () {
  var _globbedBrowserify4;

  var updateEntries;
  return _globbedBrowserify4 = globbedBrowserify, updateEntries = _globbedBrowserify4.updateEntries, _globbedBrowserify4;
});